# amieclient
![Python package testing status](https://github.com/xsede/amieclient/workflows/Python%20package/badge.svg)

Python library for the AMIE REST API

See [the docs](https://xsede.github.io/amieclient/) for API documentation.

See [examples](./examples) for examples of usage
